# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import arlas_tagger_api_python
from arlas_tagger_api_python.rest import ApiException
from arlas_tagger_api_python.models.propagation import Propagation


class TestPropagation(unittest.TestCase):
    """ Propagation unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPropagation(self):
        """
        Test Propagation
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = arlas_tagger_api_python.models.propagation.Propagation()
        pass


if __name__ == '__main__':
    unittest.main()
