# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error import Error
from .expression import Expression
from .failure import Failure
from .filter import Filter
from .form import Form
from .page import Page
from .projection import Projection
from .propagation import Propagation
from .search import Search
from .tag import Tag
from .tag_request import TagRequest
from .update_response import UpdateResponse
