# coding: utf-8

"""
    ARLAS Tagger API

    (Un)Tag fields of ARLAS collections

    OpenAPI spec version: 11.0.1
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.error import Error
from .models.expression import Expression
from .models.failure import Failure
from .models.filter import Filter
from .models.form import Form
from .models.page import Page
from .models.projection import Projection
from .models.propagation import Propagation
from .models.search import Search
from .models.tag import Tag
from .models.tag_request import TagRequest
from .models.update_response import UpdateResponse

# import apis into sdk package
from .apis.status_api import StatusApi
from .apis.write_api import WriteApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
